﻿using Microsoft.Office.Interop.Word;
/* Formatter.cs
 * part of zaaReloaded2
 * 
 * Copyright 2015 Daniel Kraus
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace zaaReloaded2.Medication
{
    /// <summary>
    /// Formats prescriptions
    /// </summary>
    public class Formatter
    {
        #region Properties

        public IList<Prescription> Prescriptions { get; set; }

        #endregion

        #region Constructor

        public Formatter() { }

        public Formatter(IList<Prescription> prescriptions)
            : this()
        {
            Prescriptions = prescriptions;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Writes a block of prescriptions with one column to a
        /// Word document.
        /// </summary>
        /// <param name="document"></param>
        public void FormatOneColumn(Document document)
        {
            if (document == null)
            {
                throw new ArgumentNullException(
                    "Cannot format prescriptions because no document was given.");
            }

            Helpers.StartUndo("Medikation formatieren");
            foreach (Prescription p in Prescriptions)
            {
                document.ActiveWindow.Selection.TypeText(p.ToString() + "\r");
            }
            Helpers.EndUndo();
        }

        /// <summary>
        /// Creates a table containing all prescriptions and copies it to
        /// the clipboard.
        /// </summary>
        public void CreatePrescriptionsTable()
        {
            throw new NotImplementedException();
        }

        #endregion
    }
}
